@@ -66,7 +66,6 @@ from fief.repositories import (
     UserPermissionRepository,
     UserRoleRepository,
 )
-from fief.settings import settings
 from fief.tasks import SendTask
 from fief.templates import templates
 
@@ -78,6 +77,12 @@ async def get_columns(
 ) -> list[DatatableColumn]:
     return [
         DatatableColumn("Email address", "email", "email_column", ordering="email"),
+        DatatableColumn(
+            "Created at", "created_at", "created_at_column", ordering="created_at"
+        ),
+        DatatableColumn(
+            "Updated at", "updated_at", "updated_at_column", ordering="updated_at"
+        ),
         DatatableColumn("ID", "id", "id_column", ordering="id"),
         DatatableColumn("Tenant", "tenant", "tenant_column", ordering="tenant.name"),
         *[
@@ -95,7 +100,7 @@ async def get_columns(
 async def get_list_context(
     columns: list[DatatableColumn] = Depends(get_columns),
     datatable_query_parameters: DatatableQueryParameters = Depends(
-        DatatableQueryParametersGetter(["email", "id", "tenant"])
+        DatatableQueryParametersGetter(["email", "created_at", "id", "tenant"])
     ),
     paginated_users: PaginatedObjects[User] = Depends(get_paginated_users),
 ):
@@ -303,7 +308,7 @@ async def create_user_access_token(
             user,
             data["scopes"],
             permissions,
-            settings.access_id_token_lifetime_seconds,
+            client.access_id_token_lifetime_seconds,
         )
 
         audit_logger(
@@ -319,7 +324,7 @@ async def create_user_access_token(
                 **list_context,
                 "user": user,
                 "access_token": access_token,
-                "expires_in": settings.access_id_token_lifetime_seconds,
+                "expires_in": client.access_id_token_lifetime_seconds,
             },
         )
 
