@@ -3,10 +3,12 @@ from pydantic import UUID4
 from sqlalchemy import select
 
 from fief.dependencies.pagination import (
+    GetPaginatedObjects,
     Ordering,
+    PaginatedObjects,
     Pagination,
     get_ordering,
-    get_paginated_objects,
+    get_paginated_objects_getter,
     get_pagination,
 )
 from fief.dependencies.workspace_repositories import get_workspace_repository
@@ -16,15 +18,22 @@ from fief.repositories import ClientRepository
 
 async def get_paginated_clients(
     query: str | None = Query(None),
+    tenant: UUID4 | None = Query(None),
     pagination: Pagination = Depends(get_pagination),
     ordering: Ordering = Depends(get_ordering),
     repository: ClientRepository = Depends(get_workspace_repository(ClientRepository)),
-) -> tuple[list[Client], int]:
+    get_paginated_objects: GetPaginatedObjects[Client] = Depends(
+        get_paginated_objects_getter
+    ),
+) -> PaginatedObjects[Client]:
     statement = select(Client)
 
     if query is not None:
         statement = statement.where(Client.name.ilike(f"%{query}%"))
 
+    if tenant is not None:
+        statement = statement.where(Client.tenant_id == tenant)
+
     return await get_paginated_objects(statement, pagination, ordering, repository)
 
 
