@@ -1,5 +1,4 @@
 from datetime import datetime
-from typing import Optional
 
 from pydantic import UUID4
 
@@ -16,4 +15,4 @@ class OAuthAccount(UUIDSchema, CreatedUpdatedAt):
 class OAuthAccountAccessToken(UUIDSchema):
     account_id: str
     access_token: str
-    expires_at: Optional[datetime]
+    expires_at: datetime | None
